import { useSearchParams } from 'react-router-dom';
import { Header } from '../components/Header';
import { FeaturedSection } from '../components/FeaturedSection';
import { useBackgroundImage } from '../hooks/useBackgroundImage';
import { CategoryName } from '../types';

export function HomePage() {
  const [searchParams] = useSearchParams();
  const categoryName = searchParams.get('category') as CategoryName;
  const backgroundImage = useBackgroundImage(categoryName);

  console.log(categoryName)

  const getHeroTitle = () => {
    if (categoryName) {
      return {
        main: getCategoryTitle(categoryName),
        sub: getCategoryDescription(categoryName),
        description: getCategoryText(categoryName)
      };
    }
    return {
      main: 'Discover the World of',
      sub: 'Все о культуре Москвы и Петербурга',
      description: 'Следите за событиями культурной жизни столиц: концерты, выставки, спектакли и многое другое в одном удобном формате.'
    };
  };

  const getCategoryTitle = (name: CategoryName): string => {
    const title = {
      Film: 'Кино',
      Theater: 'Театр',
      Music: 'Музыка',
      Sports: 'Спорт',
      Art: 'Искусство',
      Legends: 'Легенды',
      Anniversaries: 'Юбилеи',
      Memory: 'Память'
    };
    return title[name];
  };

  const getCategoryDescription = (name: CategoryName): string => {
    const descriptions = {
      Film: 'Свет, камера, действие! Магия кино',
      Theater: 'Гармония актёра и зрителя',
      Music: 'Мелодии двух столиц',
      Sports: 'Сила, движение, победа',
      Art: 'Шедевры говорят с нами',
      Legends: 'Истории, которые вдохновляют',
      Anniversaries: 'Вехи истории и великие даты',
      Memory: 'Память о великом и наследие'
    };
    return descriptions[name];
  };

  const getCategoryText = (name: CategoryName): string => {
    const subtexts = {
      Film: 'Узнайте о кино-премьерах, фестивалях и знаковых фильмах Москвы и Петербурга. Мир кино открывается для вас.',
      Theater: 'Откройте для себя театральные премьеры и закулисье лучших сцен Москвы и Петербурга.',
      Music: 'Исследуйте богатый музыкальный мир двух столиц. Узнайте о лучших исполнителях и событиях.',
      Sports: 'Спорт — это не только движение, но и культура. Откройте для себя спортивные события двух столиц.',
      Art: 'Откройте богатство искусства Москвы и Петербурга: от классики до современного авангарда.',
      Legends: 'Узнайте о великих личностях Москвы и Петербурга. Легенды, которые формируют культуру.',
      Anniversaries: 'Погрузитесь в исторические события и юбилеи, которые оставляют след в культуре двух столиц.',
      Memory: 'Сохраняем культурные традиции и память о великих событиях и людях.'
    };
    return subtexts[name];
  };

  const { main, sub, description } = getHeroTitle();

  return (
    <>
      <Header />
      <main>
        <div className="max-w-7xl mx-auto py-6 sm:px-6 lg:px-8">
          <div className="px-4 py-6 sm:px-0">
            <div className="relative">
              <div className="absolute inset-0">
                <div 
                  className="w-full h-full bg-cover bg-center transition-all duration-500 ease-in-out"
                  style={{
                    backgroundImage: `url("${backgroundImage}")`,
                  }}
                >
                  <div className="absolute inset-0 bg-gradient-to-r from-gray-900/90 to-gray-900/60 backdrop-blur-sm" />
                </div>
              </div>
              <div className="relative">
                <div className="text-center max-w-4xl mx-auto py-24 px-4 sm:py-32 sm:px-6 lg:px-8">
                  <h1 className="text-4xl font-extrabold tracking-tight text-white sm:text-5xl md:text-6xl">
                    <span className="block mb-2">{main}</span>
                    <span className="block text-blue-400">{sub}</span>
                  </h1>
                  <p className="mt-6 text-xl text-gray-200 max-w-2xl mx-auto">
                    {description}
                  </p>
                  <div className="mt-8 flex justify-center space-x-4">
                  </div>
                </div>
              </div>
            </div>
            <div id="featured">
              <FeaturedSection />
            </div>
          </div>
        </div>
      </main>
    </>
  );
}