import { User } from '../types/auth';
import { Category, City } from '../types';
import { mockUsers } from '../data/mockUsers';

// In-memory storage
let users = [...mockUsers];

export const mockUserService = {
  getUsers: async (): Promise<User[]> => {
    return new Promise((resolve) => {
      setTimeout(() => {
        resolve(users);
      }, 500); // Simulate network delay
    });
  },

  updateUserPermissions: async (userId: string, permissions: User['permissions']): Promise<User> => {
    return new Promise((resolve, reject) => {
      setTimeout(() => {
        const userIndex = users.findIndex(user => user.id === userId);
        if (userIndex === -1) {
          reject(new Error('User not found'));
          return;
        }

        const updatedUser = {
          ...users[userIndex],
          permissions: {
            ...permissions,
            // Ensure admin status cannot be changed through this method
            isAdmin: users[userIndex].permissions.isAdmin
          }
        };

        users = [
          ...users.slice(0, userIndex),
          updatedUser,
          ...users.slice(userIndex + 1)
        ];

        resolve(updatedUser);
      }, 300);
    });
  }
};