import axios from '../utils/api';
import { User } from '../types/auth';

export const userService = {
  getUsers: async (): Promise<User[]> => {
    try {
      const response = await axios.get('/users');
      return response.data;
    } catch (error) {
      console.error('Error fetching users:', error);
      throw new Error('Failed to fetch users');
    }
  },

  updateUserPermissions: async (userId: string, permissions: User['permissions']): Promise<User> => {
    try {
      const response = await axios.put(`/users/${userId}/permissions`, { permissions });
      return response.data;
    } catch (error) {
      console.error('Error updating user permissions:', error);
      throw new Error('Failed to update user permissions');
    }
  }
};